==> mysql-5.7_5.7.33.orig.tar.gz: mysql-5.7.33/include/dur_prop.h <==
/* Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef _my_dur_prop_h
#define _my_dur_prop_h

enum durability_properties
{
  /*
    Preserves the durability properties defined by the engine
  */
  HA_REGULAR_DURABILITY= 0,
  /*
     Ignore the durability properties defined by the engine and
     write only in-memory entries.
  */
  HA_IGNORE_DURABILITY= 1
};

#endif /* _my_dur_prop_h */

==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/include/dur_prop.h <==
/* Copyright (c) 2013, 2015, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef _my_dur_prop_h
#define _my_dur_prop_h

/**
  @file include/dur_prop.h
*/

enum durability_properties {
  /*
    Preserves the durability properties defined by the engine
  */
  HA_REGULAR_DURABILITY = 0,
  /*
     Ignore the durability properties defined by the engine and
     write only in-memory entries.
  */
  HA_IGNORE_DURABILITY = 1
};

#endif /* _my_dur_prop_h */
